@@ -2,9 +2,13 @@
 Asynchronous implementation of get_data
 
 .. note::
-   Requires the ``async`` optional dependencies ::
+   Requires the ``async`` optional dependencies::
 
       pip install EMC-info[async]
+
+   And must be imported separately::
+
+      from emc.async_ import get_data
 """
 from typing import Tuple
 from re import split
@@ -12,8 +16,8 @@ from re import split
 from aiohttp import ClientSession
 
 HEADERS = {
-        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_5) \
-        AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2661.102 Safari/537.36"}
+        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_5) "
+        "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2661.102 Safari/537.36"}
 
 URL_TOWN = "https://earthmc.net/map/tiles/_markers_/marker_earth.json"
 URL_PLAYER = "https://earthmc.net/map/up/world/earth/"
@@ -23,7 +27,7 @@ async def get_data() -> Tuple[dict, dict]:
     """
     Returns the map data. Useful for getting multiple thingys
 
-    :returns: The map data
+    :return: The map data
     :rtype: tuple[dict,dict]
     """
     async with ClientSession() as session:
